@@ -20,10 +20,10 @@ class Command(BaseCommand):
             raise ImproperlyConfigured("South must be installed for this command to work")
 
         from categories.migration import migrate_app
-        from categories import model_registry
+        from categories import MODEL_REGISTRY
         if args:
             for app in args:
                 migrate_app(app)
         else:
-            for app in model_registry:
+            for app in MODEL_REGISTRY:
                 migrate_app(app)
