@@ -1,11 +1,9 @@
-import warnings
-
 from django.conf import settings
 from django.db.models import Q
+from django.utils.translation import ugettext_lazy as _
 
 DEFAULT_SETTINGS = {
     'ALLOW_SLUG_CHANGE': False,
-    'CACHE_VIEW_LENGTH': 600,
     'RELATION_MODELS': [],
     'M2M_REGISTRY': {},
     'FK_REGISTRY': {},
@@ -29,27 +27,11 @@ if DEFAULT_SETTINGS['SLUG_TRANSLITERATOR']:
         DEFAULT_SETTINGS['SLUG_TRANSLITERATOR'] = getattr(module, bits[-1])
     else:
         from django.core.exceptions import ImproperlyConfigured
-        raise ImproperlyConfigured("SLUG_TRANSLITERATOR must be a callable or a string.")
+        raise ImproperlyConfigured(_('%(transliterator) must be a callable or a string.') %
+                                   {'transliterator': 'SLUG_TRANSLITERATOR'})
 else:
     DEFAULT_SETTINGS['SLUG_TRANSLITERATOR'] = lambda x: x
 
-ERR_MSG = "settings.%s is deprecated; use settings.CATEGORIES_SETTINGS instead."
-
-if hasattr(settings, 'CATEGORIES_ALLOW_SLUG_CHANGE'):
-    warnings.warn(ERR_MSG % 'CATEGORIES_ALLOW_SLUG_CHANGE', DeprecationWarning)
-    DEFAULT_SETTINGS["ALLOW_SLUG_CHANGE"] = getattr(settings, 'CATEGORIES_ALLOW_SLUG_CHANGE')
-
-if hasattr(settings, 'CATEGORIES_CACHE_VIEW_LENGTH'):
-    warnings.warn(ERR_MSG % "CATEGORIES_CACHE_VIEW_LENGTH", DeprecationWarning)
-    DEFAULT_SETTINGS["CACHE_VIEW_LENGTH"] = getattr(settings, 'CATEGORIES_CACHE_VIEW_LENGTH')
-
-if hasattr(settings, 'CATEGORIES_THUMBNAIL_UPLOAD_PATH'):
-    warnings.warn(ERR_MSG % "CATEGORIES_THUMBNAIL_UPLOAD_PATH", DeprecationWarning)
-    DEFAULT_SETTINGS["THUMBNAIL_UPLOAD_PATH"] = getattr(settings, 'CATEGORIES_THUMBNAIL_UPLOAD_PATH')
-
-if hasattr(settings, 'CATEGORIES_RELATION_MODELS'):
-    warnings.warn(ERR_MSG % "CATEGORIES_RELATION_MODELS", DeprecationWarning)
-    DEFAULT_SETTINGS["RELATION_MODELS"] = getattr(settings, 'CATEGORIES_RELATION_MODELS')
 
 # Add all the keys/values to the module's namespace
 globals().update(DEFAULT_SETTINGS)
